// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KWEATHERCORE_VERSION_H
#define KWEATHERCORE_VERSION_H

#define KWEATHERCORE_VERSION_STRING "26.07.80"
#define KWEATHERCORE_VERSION_MAJOR 26
#define KWEATHERCORE_VERSION_MINOR 7
#define KWEATHERCORE_VERSION_PATCH 80
#define KWEATHERCORE_VERSION ((26<<16)|(7<<8)|(80))

#endif
